Coverage for src/paperap/models/__init__.py: 100%

1"""

2----------------------------------------------------------------------------

3

4 METADATA:

5

6 File: __init__.py

7 Project: paperap

8 Created: 2025-03-04

9 Version: 0.0.7

10 Author: Jess Mann

11 Email: jess@jmann.me

12 Copyright (c) 2025 Jess Mann

13

14----------------------------------------------------------------------------

15

16 LAST MODIFIED:

17

18 2025-03-04 By Jess Mann

19

20"""

21

22 from paperap.models.abstract import BaseModel, BaseQuerySet, StandardModel, StandardQuerySet

23 from paperap.models.correspondent import Correspondent, CorrespondentQuerySet

24 from paperap.models.custom_field import CustomField, CustomFieldQuerySet

25 from paperap.models.document import Document, DocumentNote, DocumentQuerySet, CustomFieldValues

26 from paperap.models.document_type import DocumentType, DocumentTypeQuerySet

27 from paperap.models.profile import Profile, ProfileQuerySet

28 from paperap.models.saved_view import SavedView, SavedViewQuerySet

29 from paperap.models.share_links import ShareLinks, ShareLinksQuerySet

30 from paperap.models.storage_path import StoragePath, StoragePathQuerySet

31 from paperap.models.tag import Tag, TagQuerySet

32 from paperap.models.task import Task, TaskQuerySet

33 from paperap.models.ui_settings import UISettings, UISettingsQuerySet

34 from paperap.models.user import Group, GroupQuerySet, User, UserQuerySet

35 from paperap.models.workflow import (

36 Workflow,

37 WorkflowAction,

38 WorkflowActionQuerySet,

39 WorkflowQuerySet,

40 WorkflowTrigger,

41 WorkflowTriggerQuerySet,

42)

43

44 __all__ = [

45 "BaseModel",

46 "StandardModel",

47 "DocumentNote",

48 "Document",

49 "Correspondent",

50 "Tag",

51 "DocumentType",

52 "StoragePath",

53 "CustomField",

54 "User",

55 "Group",

56 "Task",

57 "SavedView",

58 "UISettings",

59 "Workflow",

60 "WorkflowTrigger",

61 "WorkflowAction",

62 "Profile",

63 "ShareLinks",

64 "BaseQuerySet",

65 "StandardQuerySet",

66 "DocumentQuerySet",

67 "CorrespondentQuerySet",

68 "TagQuerySet",

69 "DocumentTypeQuerySet",

70 "StoragePathQuerySet",

71 "CustomFieldQuerySet",

72 "UserQuerySet",

73 "GroupQuerySet",

74 "TaskQuerySet",

75 "SavedViewQuerySet",

76 "UISettingsQuerySet",

77 "WorkflowQuerySet",

78 "WorkflowTriggerQuerySet",

79 "WorkflowActionQuerySet",

80 "ProfileQuerySet",

81 "ShareLinksQuerySet",

82]